@@ -1,11 +1,11 @@
 # Human friendly input/output in Python.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: May 10, 2014
+# Last Change: May 11, 2014
 # URL: https://humanfriendly.readthedocs.org
 
 # Semi-standard module versioning.
-__version__ = '1.8'
+__version__ = '1.8.1'
 
 # Standard library modules.
 import math
@@ -257,9 +257,10 @@ def concatenate(items):
     """
     Concatenate a list of items in a human friendly way.
 
-    :param items: A list of strings.
+    :param items: A sequence of strings.
     :returns: A single string.
     """
+    items = list(items)
     if len(items) > 1:
         return ', '.join(items[:-1]) + ' and ' + items[-1]
     elif items:
@@ -273,11 +274,15 @@ class Timer(object):
     Easy to use timer to keep track of long during operations.
     """
 
-    def __init__(self):
+    def __init__(self, start_time=None):
         """
         Remember the time when the :py:class:`Timer` was created.
+
+        :param start_time: The start time (a float, defaults to the current time).
         """
-        self.start_time = time.time()
+        if start_time is None:
+            start_time = time.time()
+        self.start_time = start_time
 
     @property
     def elapsed_time(self):
